==> zio-aws-fms_2.13-5.17.271.1-sources.jar: zio/aws/fms/model/PutPolicyResponse.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.ResourceArn
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutPolicyResponse(
    policy: Optional[zio.aws.fms.model.Policy] = Optional.Absent,
    policyArn: Optional[ResourceArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.PutPolicyResponse = {
    import PutPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.PutPolicyResponse
      .builder()
      .optionallyWith(policy.map(value => value.buildAwsValue()))(_.policy)
      .optionallyWith(
        policyArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.policyArn)
      .build()
  }
  def asReadOnly: zio.aws.fms.model.PutPolicyResponse.ReadOnly =
    zio.aws.fms.model.PutPolicyResponse.wrap(buildAwsValue())
}
object PutPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.PutPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.PutPolicyResponse =
      zio.aws.fms.model.PutPolicyResponse(
        policy.map(value => value.asEditable),
        policyArn.map(value => value)
      )
    def policy: Optional[zio.aws.fms.model.Policy.ReadOnly]
    def policyArn: Optional[ResourceArn]
    def getPolicy: ZIO[Any, AwsError, zio.aws.fms.model.Policy.ReadOnly] =
      AwsError.unwrapOptionField("policy", policy)
    def getPolicyArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("policyArn", policyArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.PutPolicyResponse
  ) extends zio.aws.fms.model.PutPolicyResponse.ReadOnly {
    override val policy: Optional[zio.aws.fms.model.Policy.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.policy())
        .map(value => zio.aws.fms.model.Policy.wrap(value))
    override val policyArn: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.policyArn())
      .map(value => zio.aws.fms.model.primitives.ResourceArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.PutPolicyResponse
  ): zio.aws.fms.model.PutPolicyResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-fms_3-5.17.126.2-sources.jar: zio/aws/fms/model/PutPolicyResponse.scala <==
package zio.aws.fms.model
import zio.ZIO
import zio.aws.fms.model.primitives.ResourceArn
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PutPolicyResponse(
    policy: Option[zio.aws.fms.model.Policy] = None,
    policyArn: Option[ResourceArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fms.model.PutPolicyResponse = {
    import PutPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fms.model.PutPolicyResponse
      .builder()
      .optionallyWith(policy.map(value => value.buildAwsValue()))(_.policy)
      .optionallyWith(
        policyArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.policyArn)
      .build()
  }
  def asReadOnly: zio.aws.fms.model.PutPolicyResponse.ReadOnly =
    zio.aws.fms.model.PutPolicyResponse.wrap(buildAwsValue())
}
object PutPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fms.model.PutPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fms.model.PutPolicyResponse =
      zio.aws.fms.model.PutPolicyResponse(
        policy.map(value => value.asEditable),
        policyArn.map(value => value)
      )
    def policy: Option[zio.aws.fms.model.Policy.ReadOnly]
    def policyArn: Option[ResourceArn]
    def getPolicy: ZIO[Any, AwsError, zio.aws.fms.model.Policy.ReadOnly] =
      AwsError.unwrapOptionField("policy", policy)
    def getPolicyArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("policyArn", policyArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fms.model.PutPolicyResponse
  ) extends zio.aws.fms.model.PutPolicyResponse.ReadOnly {
    override val policy: Option[zio.aws.fms.model.Policy.ReadOnly] = scala
      .Option(impl.policy())
      .map(value => zio.aws.fms.model.Policy.wrap(value))
    override val policyArn: Option[ResourceArn] = scala
      .Option(impl.policyArn())
      .map(value => zio.aws.fms.model.primitives.ResourceArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fms.model.PutPolicyResponse
  ): zio.aws.fms.model.PutPolicyResponse.ReadOnly = new Wrapper(impl)
}
